% main_rra.m

% run a rra simulation and update model mass parameters

% josh baxter - joshrbaxter@gmail.com
% 2018-04-05 - v1 - make call to runrra, parse output, update model

clear all; close all; clc;
import org.opensim.modeling.*

% load in model and state
osimpath = 'subject01.osim';
[modeldir,modelname,~] = fileparts(osimpath);
Params.rra.osimpath = osimpath;
Params.rra.resultsfolder = '.\rraresults';
Params.rra.toolname = 'walk';
Params.rra.kinematics = 'subject01_walk.mot';
Params.rra.tasks = 'Kinematics_Tracking_Tasks.xml';
Params.rra.extloads = 'subject01_walk_grf.xml';
Params.rra.actuators = 'Reserve_Actuators.xml';
Params.rra.replaceforce = 1; % set to true
Params.rra.cutoff = 6;
Params.rra.adjustcom = 1;
Params.rra.adjustsegcom = 'torso';
Params.rra.adjustmodelname = [modelname,'_adjusted.osim'];
Params.rra.xml = 'rra.xml';
Params.rra.rraoutput = fullfile(Params.rra.resultsfolder,'rraoutput.txt');

%% run rra
[rraoutput,rratime] = runrra(Params);

%% update new model

% parse rraoutput for mass adjustment recommendations
fid = fopen(Params.rra.rraoutput);

tline = fgetl(fid);
while ~contains(tline,'* Recommended mass adjustments:')
    tline = fgetl(fid);
end
masschangestr = fgetl(fid);

model = Model(Params.rra.adjustmodelname);
modelname = model.getName();
model.setName([char(modelname),'_adjusted'])

% get names of all bodies
bodySet = model.getBodySet();
nBodies = bodySet.getSize();

for i = 0:nBodies-1
    iStr = fgetl(fid);
    spaceind = strfind(iStr,'*');
    colonind = strfind(iStr,':');
    iBody = iStr(spaceind(1)+3:colonind(1)-1);
    newmassind = strfind(iStr,'new mass');
    iNewMass = str2num(iStr(newmassind+11:end));
    iBodyMass1 = bodySet.get(iBody).getMass();
    fprintf('Setting body %s mass from %1.3fkg to %1.3fkg...\n',iBody,iBodyMass1,iNewMass)
    bodySet.get(iBody).setMass(iNewMass);
end

% save model
model.print(Params.rra.adjustmodelname);

% clear model from memory
model.delete();
clear model