function [output,runtime] = runrra(Params)

% josh baxter - joshrbaxter@gmail.com 
% v1 - 2018-04-05
import org.opensim.modeling.*

[~,modelname,~] = fileparts(Params.rra.osimpath);
[~,trialname,~] = fileparts(Params.rra.kinematics);
fprintf('running RRA tool for %s - %s...\n',modelname,trialname)

rraTool = RRATool();
rraTool.setName(Params.rra.toolname);
rraTool.setModelFilename(Params.rra.osimpath);
rraTool.setResultsDir(Params.rra.resultsfolder);
rraTool.setDesiredKinematicsFileName(Params.rra.kinematics);
rraTool.setLowpassCutoffFrequency(Params.rra.cutoff);
rraTool.setTaskSetFileName(Params.rra.tasks);
rraTool.setExternalLoadsFileName(Params.rra.extloads)

% set the actuators
if isfield(Params.rra,'actuators')
    forceSet = ArrayStr();
    forceSet.append(Params.rra.actuators);
    rraTool.setForceSetFiles(forceSet); 
    
    % set replace force if user indicated and actuator file exists
    if isfield(Params.rra,'replaceforce')
        rraTool.setReplaceForceSet(Params.rra.replaceforce);
    end
    
end

% adjust model COM on segment
if isfield(Params.rra,'adjustcom')
    rraTool.setAdjustCOMToReduceResiduals(Params.rra.adjustcom);
    rraTool.setAdjustedCOMBody(Params.rra.adjustsegcom);
    rraTool.setOutputModelFileName(Params.rra.adjustmodelname);
end

% set time
if ~isfield(Params.rra,'time')
    coordData = Storage(Params.rra.kinematics);
    Params.rra.time(1) = coordData.getFirstTime();
    Params.rra.time(2) = coordData.getLastTime();
end
rraTool.setStartTime(Params.rra.time(1));
rraTool.setFinalTime(Params.rra.time(2));

% save rra setup file
rraTool.print(Params.rra.xml);

% run rra analysis thru command line
tic
[~,output] = dos(['rra -S ',Params.rra.xml]);
runtime = toc;

% right rra ouput to file
fid = fopen(Params.rra.rraoutput,'w+');
fprintf(fid,output);
fclose(fid);
